@@ -173,7 +173,7 @@ class KinesisFirehoseToAnalyticsAndS3(
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
-        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
+        :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
         :param kinesis_analytics_props: Optional user-provided props to override the default props for the Kinesis Analytics application. Default: - Default props are used.
         :param kinesis_firehose_props: Optional user-provided props to override the default props for the Kinesis Firehose delivery stream. Default: - Default props are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
@@ -247,7 +247,7 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         '''The properties for the KinesisFirehoseToAnalyticsAndS3 class.
 
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
-        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
+        :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
         :param kinesis_analytics_props: Optional user-provided props to override the default props for the Kinesis Analytics application. Default: - Default props are used.
         :param kinesis_firehose_props: Optional user-provided props to override the default props for the Kinesis Firehose delivery stream. Default: - Default props are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
@@ -281,7 +281,7 @@ class KinesisFirehoseToAnalyticsAndS3Props:
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
-        '''Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
+        '''Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error.
 
         :default: - None
         '''
